package sun.java2d.pipe;

import java.awt.geom.GeneralPath;
import java.awt.Shape;
import java.awt.geom.Arc2D;
import java.awt.geom.Ellipse2D;
import java.awt.geom.RoundRectangle2D;
import java.awt.Rectangle;
import java.awt.geom.Line2D;
import sun.java2d.SunGraphics2D;

public class PixelToShapeConverter implements PixelDrawPipe, PixelFillPipe
{
    ShapeDrawPipe outpipe;
    
    public PixelToShapeConverter(ShapeDrawPipe outpipe) {
        this.outpipe = outpipe;
    }
    
    @Override
    public void drawLine(SunGraphics2D sunGraphics2D, int n, int n2, int n3, int n4) {
        this.outpipe.draw(sunGraphics2D, new Line2D.Float((float)n, (float)n2, (float)n3, (float)n4));
    }
    
    @Override
    public void drawRect(SunGraphics2D sunGraphics2D, int x, int y, int width, int height) {
        this.outpipe.draw(sunGraphics2D, new Rectangle(x, y, width, height));
    }
    
    @Override
    public void fillRect(SunGraphics2D sunGraphics2D, int x, int y, int width, int height) {
        this.outpipe.fill(sunGraphics2D, new Rectangle(x, y, width, height));
    }
    
    @Override
    public void drawRoundRect(SunGraphics2D sunGraphics2D, int n, int n2, int n3, int n4, int n5, int n6) {
        this.outpipe.draw(sunGraphics2D, new RoundRectangle2D.Float((float)n, (float)n2, (float)n3, (float)n4, (float)n5, (float)n6));
    }
    
    @Override
    public void fillRoundRect(SunGraphics2D sunGraphics2D, int n, int n2, int n3, int n4, int n5, int n6) {
        this.outpipe.fill(sunGraphics2D, new RoundRectangle2D.Float((float)n, (float)n2, (float)n3, (float)n4, (float)n5, (float)n6));
    }
    
    @Override
    public void drawOval(SunGraphics2D sunGraphics2D, int n, int n2, int n3, int n4) {
        this.outpipe.draw(sunGraphics2D, new Ellipse2D.Float((float)n, (float)n2, (float)n3, (float)n4));
    }
    
    @Override
    public void fillOval(SunGraphics2D sunGraphics2D, int n, int n2, int n3, int n4) {
        this.outpipe.fill(sunGraphics2D, new Ellipse2D.Float((float)n, (float)n2, (float)n3, (float)n4));
    }
    
    @Override
    public void drawArc(SunGraphics2D sunGraphics2D, int n, int n2, int n3, int n4, int n5, int n6) {
        this.outpipe.draw(sunGraphics2D, new Arc2D.Float((float)n, (float)n2, (float)n3, (float)n4, (float)n5, (float)n6, 0));
    }
    
    @Override
    public void fillArc(SunGraphics2D sunGraphics2D, int n, int n2, int n3, int n4, int n5, int n6) {
        this.outpipe.fill(sunGraphics2D, new Arc2D.Float((float)n, (float)n2, (float)n3, (float)n4, (float)n5, (float)n6, 2));
    }
    
    private Shape makePoly(int[] array, int[] array2, int n, boolean b) {
        GeneralPath generalPath = new GeneralPath(0);
        if (n > 0) {
            generalPath.moveTo((float)array[0], (float)array2[0]);
            for (int i = 1; i < n; ++i) {
                generalPath.lineTo((float)array[i], (float)array2[i]);
            }
            if (b) {
                generalPath.closePath();
            }
        }
        return generalPath;
    }
    
    @Override
    public void drawPolyline(SunGraphics2D sunGraphics2D, int[] array, int[] array2, int n) {
        this.outpipe.draw(sunGraphics2D, this.makePoly(array, array2, n, false));
    }
    
    @Override
    public void drawPolygon(SunGraphics2D sunGraphics2D, int[] array, int[] array2, int n) {
        this.outpipe.draw(sunGraphics2D, this.makePoly(array, array2, n, true));
    }
    
    @Override
    public void fillPolygon(SunGraphics2D sunGraphics2D, int[] array, int[] array2, int n) {
        this.outpipe.fill(sunGraphics2D, this.makePoly(array, array2, n, true));
    }
}
